pub fn to_lindist3flow_opf_instance(
module: &PioModule<PioValue>,
) -> Result<PioModule<LinDist3FlowOpfInstance>, Error>Expand description
Construct a LinDist3Flow optimal power flow calculation from a multiconductor network module using the default formulation options.
An already typed LinDist3Flow instance is extracted without reconstruction or another history entry.